Struct
MalcontentWebFilterBuilder
unstable since: 0.14.0
Description [src]
struct MctWebFilterBuilder {
/* No available fields */
}
MctWebFilterBuilder is a stack-allocated mutable structure
used to build a MctWebFilter instance.
Use mct_web_filter_builder_init(), various method calls to set
properties of the web filter, and then
mct_web_filter_builder_end(), to construct a
MctWebFilter.
Available since: 0.14.0
Instance methods
mct_web_filter_builder_add_allow_list
Adds a allow list to the MctWebFilter, mapping the given id
to a filter list downloadable at filter_uri.
unstable since: 0.14.0
mct_web_filter_builder_add_block_list
Adds a block list to the MctWebFilter, mapping the given id
to a filter list downloadable at filter_uri.
unstable since: 0.14.0
mct_web_filter_builder_add_custom_allow_list_entry
Adds a single hostname to the MctWebFilter, to be allowed.
unstable since: 0.14.0
mct_web_filter_builder_add_custom_block_list_entry
Adds a single hostname to the MctWebFilter, to be blocked.
unstable since: 0.14.0
mct_web_filter_builder_clear
Clear builder, freeing any internal state in it.
unstable since: 0.14.0
mct_web_filter_builder_copy
Copy the given builder to a newly-allocated
MctWebFilterBuilder on the heap.
unstable since: 0.14.0
mct_web_filter_builder_end
Finish constructing an MctWebFilter with the given builder,
and return it.
unstable since: 0.14.0
mct_web_filter_builder_free
Free an MctWebFilterBuilder originally allocated using
mct_web_filter_builder_new().
unstable since: 0.14.0
mct_web_filter_builder_init
Initialise the given builder so it can be used to construct a new
MctWebFilter.
unstable since: 0.14.0
mct_web_filter_builder_set_filter_type
Set the type of web filter to apply to the user.
unstable since: 0.14.0
mct_web_filter_builder_set_force_safe_search
Sets the safe search preference for the MctWebFilter.
unstable since: 0.14.0